@@ -334,14 +334,10 @@ int __aug_close_memstream(struct memstream *ms) {
     return 0;
 }
 
-char *path_expand(struct tree *tree, const char *ppath) {
+int tree_sibling_index(struct tree *tree) {
     struct tree *siblings = tree->parent->children;
 
-    char *path;
-    const char *label;
-    char *escaped = NULL;
-
-    int cnt = 0, ind = 0, r;
+    int cnt = 0, ind = 0;
 
     list_for_each(t, siblings) {
         if (streqv(t->label, tree->label)) {
@@ -351,6 +347,21 @@ char *path_expand(struct tree *tree, const char *ppath) {
         }
     }
 
+    if (cnt > 1) {
+        return ind;
+    } else {
+        return 0;
+    }
+}
+
+char *path_expand(struct tree *tree, const char *ppath) {
+    char *path;
+    const char *label;
+    char *escaped = NULL;
+    int r;
+
+    int ind = tree_sibling_index(tree);
+
     if (ppath == NULL)
         ppath = "";
 
@@ -366,7 +377,7 @@ char *path_expand(struct tree *tree, const char *ppath) {
     if (escaped != NULL)
         label = escaped;
 
-    if (cnt > 1) {
+    if (ind > 0) {
         r = asprintf(&path, "%s/%s[%d]", ppath, label, ind);
     } else {
         r = asprintf(&path, "%s/%s", ppath, label);
