@@ -2388,7 +2388,6 @@ static struct term *make_ident(char *qname, struct info *locp) {
 static struct term *make_unit_term(struct info *locp) {
   struct term *term = make_term_locp(A_VALUE, locp);
   term->value = make_unit(ref(term->info));
-  term->type = make_base_type(T_UNIT);
   return term;
 }
 
@@ -2396,7 +2395,6 @@ static struct term *make_string_term(char *value, struct info *locp) {
   struct term *term = make_term_locp(A_VALUE, locp);
   term->value = make_value(V_STRING, ref(term->info));
   term->value->string = make_string(value);
-  term->type = make_base_type(T_STRING);
   return term;
 }
 
@@ -2404,7 +2402,6 @@ static struct term *make_regexp_term(char *pattern, int nocase,
                                      struct info *locp) {
   struct term *term = make_term_locp(A_VALUE, locp);
   term->value = make_value(V_REGEXP, ref(term->info));
-  term->type = make_base_type(T_REGEXP);
   term->value->regexp = make_regexp(term->info, pattern, nocase);
   return term;
 }
@@ -2452,7 +2449,6 @@ static struct term *make_tree_value(struct tree *tree, struct info *locp) {
   struct term *term = make_term_locp(A_VALUE, locp);
   struct value *value = make_value(V_TREE, ref(term->info));
   value->origin = make_tree_origin(tree);
-  term->type = make_base_type(T_TREE);
   term->value = value;
   return term;
 }
