@@ -80,7 +80,8 @@ static void put_error(struct state *state, struct lens *lens,
     if (state->error != NULL)
         return;
 
-    CALLOC(state->error, 1);
+    if (ALLOC(state->error) < 0)
+        return;
     state->error->lens = ref(lens);
     state->error->pos  = -1;
     if (strlen(state->path) == 0) {
@@ -174,7 +175,8 @@ static struct split *split_append(struct split **split, struct split *tail,
                                   struct tree *tree, struct tree *follow,
                                   char *enc, size_t start, size_t end) {
     struct split *sp;
-    CALLOC(sp, 1);
+    if (ALLOC(sp) < 0)
+        return NULL;
     sp->tree = tree;
     sp->follow = follow;
     sp->enc = enc;
@@ -217,6 +219,8 @@ static struct split *split_concat(struct state *state, struct lens *lens) {
         for (int i=0; i < lens->nchildren; i++) {
             tail = split_append(&split, tail, NULL, NULL,
                                 outer->enc, 0, 0);
+            if (tail == NULL)
+                goto error;
         }
         return split;
     }
