@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2015 David Lutterkort
+ * Copyright (C) 2009-2016 David Lutterkort
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -109,6 +109,13 @@ int remove_file(struct augeas *aug, struct tree *tree);
 /* Return a printable name for the transform XFM. Never returns NULL. */
 const char *xfm_lens_name(struct tree *xfm);
 
+/* Return the lens and its name from the transform XFM. LENS_NAME may be
+   NULL, in which case the name of the lens is not returned, only the lens
+   itself.
+*/
+struct lens *xfm_lens(struct augeas *aug,
+                      struct tree *xfm, const char **lens_name);
+
 /* Store a file-specific transformation error in /augeas/files/PATH/error */
 ATTRIBUTE_FORMAT(printf, 4, 5)
 void transform_file_error(struct augeas *aug, const char *status,
